/**
 * Creates a validation functions that parses the Zod schema of a form.
 *
 * @param schema A Zod schema.
 *
 * @returns A validation function.
 */
export function zodForm(schema) {
    return (values) => {
        const result = schema.safeParse(values);
        const formErrors = {};
        if (!result.success) {
            for (const issue of result.error.issues) {
                const path = issue.path.join('.');
                if (!formErrors[path]) {
                    formErrors[path] = issue.message;
                }
            }
        }
        return formErrors;
    };
}
